@@ -1,7 +1,10 @@
 import typer
 from typing_extensions import Annotated
 
+app = typer.Typer()
 
+
+@app.command()
 def main(
     project_name: Annotated[str, typer.Option(prompt=True, confirmation_prompt=True)],
 ):
@@ -9,4 +12,4 @@ def main(
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
