@@ -3,7 +3,10 @@ from typing import Optional
 import typer
 from typing_extensions import Annotated
 
+app = typer.Typer()
 
+
+@app.command()
 def main(accept: Annotated[Optional[bool], typer.Option("--accept/--reject")] = None):
     if accept is None:
         print("I don't know what you want yet")
@@ -14,4 +17,4 @@ def main(accept: Annotated[Optional[bool], typer.Option("--accept/--reject")] =
 
 
 if __name__ == "__main__":
-    typer.run(main)
+    app()
