@@ -2,15 +2,12 @@ import subprocess
 import sys
 from pathlib import Path
 
-import typer
 from typer.testing import CliRunner
 
 from docs_src.parameter_types.file import tutorial001_an as mod
 
 runner = CliRunner()
-
-app = typer.Typer()
-app.command()(mod.main)
+app = mod.app
 
 
 def test_main(tmpdir):
