@@ -2,15 +2,12 @@ import subprocess
 import sys
 from pathlib import Path
 
-import typer
 from typer.testing import CliRunner
 
 from docs_src.parameter_types.file import tutorial004 as mod
 
 runner = CliRunner()
-
-app = typer.Typer()
-app.command()(mod.main)
+app = mod.app
 
 
 def test_main(tmpdir):
@@ -18,7 +15,7 @@ def test_main(tmpdir):
     if binary_file.exists():  # pragma: no cover
         binary_file.unlink()
     result = runner.invoke(app, ["--file", f"{binary_file}"])
-    text = binary_file.read_text()
+    text = binary_file.read_text(encoding="utf-8")
     binary_file.unlink()
     assert result.exit_code == 0
     assert "Binary file written" in result.output
